@@ -1,6 +1,6 @@
+from __future__ import unicode_literals
 import re
-import string
-import unicodedata
+
 
 class StringProcessor(object):
     """
@@ -10,12 +10,13 @@ class StringProcessor(object):
     """
 
     @classmethod
-    def replace_non_lettters_non_numbers_with_whitespace(cls, a_string):
+    def replace_non_letters_non_numbers_with_whitespace(cls, a_string):
         """
-        This function replaces any sequence of non letters and non numbers with a single white space.
+        This function replaces any sequence of non letters and non
+        numbers with a single white space.
         """
         regex = re.compile(r"(?ui)\W")
-        return regex.sub(u" ", a_string)
+        return regex.sub(" ", a_string)
 
     @classmethod
     def strip(cls, a_string):
@@ -38,4 +39,3 @@ class StringProcessor(object):
         This function returns the upper-cased version of the string given.
         """
         return a_string.upper()
-
